@@ -18,6 +18,7 @@ except ImportError:
 from .logger import LOG_COLORS
 from .logger import EncodingStreamHandler as StreamHandler
 from kolibri.utils.compat import monkey_patch_collections
+from kolibri.utils.compat import monkey_patch_translation
 
 
 logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
@@ -126,6 +127,8 @@ def set_env():
 
     monkey_patch_collections()
 
+    monkey_patch_translation()
+
     sys.path = [os.path.realpath(os.path.dirname(kolibri_dist.__file__))] + sys.path
 
     # Add path for c extensions to sys.path
